@@ -28,6 +28,11 @@ const walls_config: { [key: string]: any } = {
     dash: [5, 5],
   },
 };
+
+let MAX_WIDTH = 600;
+let MAX_HEIGHT = 450;
+let MAX_ROWS = 20;
+let MAX_COLS = 20;
 export class WorldModel {
   rows: number;
   cols: number;
@@ -67,11 +72,14 @@ export class WorldModel {
     tiles = [],
     pending_goals = []
   ) {
-    this.rows = rows;
-    this.cols = cols;
+    this.rows = Math.min(MAX_ROWS, rows);
+    this.cols = Math.min(MAX_COLS, cols);
     this.vwalls = vwalls;
     this.hwalls = hwalls;
-    this.bs = Math.min(500.0 / rows, 50); //box_size
+    this.bs = Math.ceil(
+      Math.min(MAX_HEIGHT / this.rows, MAX_WIDTH / this.cols, 50)
+    );
+
     this.height = rows * this.bs;
     this.width = cols * this.bs;
     this.objects = objects;
@@ -133,12 +141,12 @@ export class WorldModel {
     let msgHeight = 150;
     let stage = new Konva.Stage({
       container: 'container',
-      width: this.width + this.bs + padding,
+      width: Math.max(this.width, 500) + this.bs + padding,
       height: this.height + this.bs + padding + msgHeight,
     });
 
     this.ui.layers.msg = new Konva.Layer({
-      width: this.width + this.bs + padding,
+      width: 500 + this.bs + padding,
       height: msgHeight,
     });
 
@@ -191,16 +199,16 @@ export class WorldModel {
       old_msg.destroy();
     }
 
-    let msg = msgs.slice(0, 6).join('\n\n');
+    let msg = msgs.slice(0, 6).join('\n');
     let rect_width = Math.max(msg_layer?.width() || 0, 200) - 70;
     let text = new Konva.Text({
-      padding: 20,
+      padding: 10,
       text: msg,
       x: 40,
       y: 40,
-      align: 'center',
+      align: 'left',
       fill: color,
-      verticalAlign: 'center',
+      lineHeight: 1.2,
       fontSize: fontSize,
       width: rect_width,
       name: 'instruction_msg-rect',
