@@ -42,7 +42,13 @@ class Maze(DOMWidget):
     def js_call(self, method_name, params): 
         # print("calling method: " + method_name)
         cb = datetime.now().strftime('%f')
-        
+
+        if self.model.js_call_counter == 10:
+            _time.sleep(0.2)
+            self.model.js_call_counter = 0
+            
+        self.model.js_call_counter +=1
+
         if self.model.has_balance():
             self.current_call = json.dumps({'method_name': method_name, 'params': params, 'cb': cb})
         else:
